@@ -12,6 +12,7 @@
 #![feature(core_intrinsics)]
 #![feature(nonzero_ops)]
 #![feature(half_open_range_patterns)]
+#![feature(bigint_helper_methods)]
 
 mod binary;
 pub use binary::Binary;
@@ -34,12 +35,14 @@ pub use non_zero::sign::NonZeroSigned;
 
 mod rational;
 pub use rational::RationalBig;
+pub use rational::RationalUsize;
 pub use rational::Rational128;
 pub use rational::Rational64;
 pub use rational::Rational32;
 pub use rational::Rational16;
 pub use rational::Rational8;
 pub use rational::NonZeroRationalBig;
+pub use rational::NonZeroRationalUsize;
 pub use rational::NonZeroRational128;
 pub use rational::NonZeroRational64;
 pub use rational::NonZeroRational32;
@@ -49,6 +52,7 @@ pub use rational::NonZeroRational8;
 mod sign;
 pub use sign::Sign;
 pub use sign::Signed;
+pub use sign::Negateable;
 
 mod traits;
 pub use traits::Abs;
