@@ -3,19 +3,21 @@ use std::iter::Sum;
 use std::ops::{Add, AddAssign, Div, DivAssign, Mul, MulAssign, Sub, SubAssign};
 use std::ops::Neg;
 
+use crate::Negateable;
 use crate::non_zero::NonZero;
 use crate::non_zero::NonZeroSign;
-use crate::rational::small::{Rational128, Rational16, Rational32, Rational64, Rational8};
-use crate::rational::small::{NonZeroRational128, NonZeroRational16, NonZeroRational32, NonZeroRational64, NonZeroRational8};
-use crate::rational::small::ops::building_blocks::{add128, add16, add32, add64, add8};
-use crate::rational::small::ops::building_blocks::{sub128, sub16, sub32, sub64, sub8};
-use crate::rational::small::ops::building_blocks::{mul128, mul16, mul32, mul64, mul8};
+use crate::rational::small::{Rational128, Rational16, Rational32, Rational64, Rational8, RationalUsize};
+use crate::rational::small::{NonZeroRational128, NonZeroRational16, NonZeroRational32, NonZeroRational64, NonZeroRational8, NonZeroRationalUsize};
+use crate::rational::small::ops::building_blocks::{add128, add16, add32, add64, add8, add_usize};
+use crate::rational::small::ops::building_blocks::{sub128, sub16, sub32, sub64, sub8, sub_usize};
+use crate::rational::small::ops::building_blocks::{mul128, mul16, mul32, mul64, mul8, mul_usize};
 use crate::rational::small::ops::building_blocks::SignChange;
 use crate::sign::Sign;
 
 pub(crate) mod building_blocks;
 mod with_int;
 mod with_one;
+mod with_zero;
 
 #[cfg(test)]
 mod test;
@@ -43,7 +45,7 @@ macro_rules! rational {
                         );
                         match sign_change {
                             SignChange::None => {}
-                            SignChange::Flip => self.sign = !self.sign,
+                            SignChange::Flip => self.sign.negate(),
                             SignChange::Zero => self.sign = Sign::Zero,
                         }
                     }
@@ -72,7 +74,7 @@ macro_rules! rational {
                         );
                         match sign_change {
                             SignChange::None => {}
-                            SignChange::Flip => self.sign = !self.sign,
+                            SignChange::Flip => self.sign.negate(),
                             SignChange::Zero => self.sign = Sign::Zero,
                         }
                     }
@@ -173,6 +175,7 @@ rational!(Rational16, add16, sub16, mul16);
 rational!(Rational32, add32, sub32, mul32);
 rational!(Rational64, add64, sub64, mul64);
 rational!(Rational128, add128, sub128, mul128);
+rational!(RationalUsize, add_usize, sub_usize, mul_usize);
 
 macro_rules! rational_non_zero {
     ($name:ident, $add_name:ident, $sub_name:ident, $mul_name:ident) => {
@@ -197,7 +200,7 @@ macro_rules! rational_non_zero {
                         );
                         match sign_change {
                             SignChange::None => {}
-                            SignChange::Flip => self.sign = !self.sign,
+                            SignChange::Flip => self.sign.negate(),
                             SignChange::Zero => panic!("attempt to add with overflow"),
                         }
                     }
@@ -217,7 +220,7 @@ macro_rules! rational_non_zero {
                         );
                         match sign_change {
                             SignChange::None => {}
-                            SignChange::Flip => self.sign = !self.sign,
+                            SignChange::Flip => self.sign.negate(),
                             SignChange::Zero => panic!("attempt to subtract with overflow"),
                         }
                     }
@@ -268,7 +271,7 @@ macro_rules! rational_non_zero {
             #[must_use]
             #[inline]
             fn neg(mut self) -> Self::Output {
-                self.sign = !self.sign;
+                self.sign.negate();
                 self
             }
         }
@@ -293,6 +296,7 @@ rational_non_zero!(NonZeroRational16, add16, sub16, mul16);
 rational_non_zero!(NonZeroRational32, add32, sub32, mul32);
 rational_non_zero!(NonZeroRational64, add64, sub64, mul64);
 rational_non_zero!(NonZeroRational128, add128, sub128, mul128);
+rational_non_zero!(NonZeroRationalUsize, add_usize, sub_usize, mul_usize);
 
 macro_rules! rational_requiring_wide {
     ($name:ident, $uty:ty, $BITS:literal, $wide:ty, $sign:ident) => {
@@ -536,8 +540,10 @@ rational_forward!(Rational16);
 rational_forward!(Rational32);
 rational_forward!(Rational64);
 rational_forward!(Rational128);
+rational_forward!(RationalUsize);
 rational_forward!(NonZeroRational8);
 rational_forward!(NonZeroRational16);
 rational_forward!(NonZeroRational32);
 rational_forward!(NonZeroRational64);
 rational_forward!(NonZeroRational128);
+rational_forward!(NonZeroRationalUsize);
